// java wrapper for vtkPolyDataContourLineInterpolator object
//

package vtk;
import vtk.*;

public class vtkPolyDataContourLineInterpolator extends vtkContourLineInterpolator
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int InterpolateLine_2(vtkRenderer id0,vtkContourRepresentation id1,int id2,int id3);
  public int InterpolateLine(vtkRenderer id0,vtkContourRepresentation id1,int id2,int id3)
    { return InterpolateLine_2(id0,id1,id2,id3); }

  private native long GetPolys_3();
  public vtkPolyDataCollection GetPolys() {
    long temp = GetPolys_3();

    if (temp == 0) return null;
    return (vtkPolyDataCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkPolyDataContourLineInterpolator() { super(); }

  public vtkPolyDataContourLineInterpolator(long id) { super(id); }

}
